pub struct ResolvedBirthDateTime { /* private fields */ }Expand description
The resolved local birth date/time after applying the calculation policy.
All adjustment measurements are reported for diagnostics. They are None
under SolarTimePolicy::ClockTime, where no adjustment is applied.
Implementations
Sourceimpl ResolvedBirthDateTime
impl ResolvedBirthDateTime
Sourcepub const fn input_date(&self) -> SolarDate
pub const fn input_date(&self) -> SolarDate
Returns the original input date.
Sourcepub const fn input_time(&self) -> ClockBirthTime
pub const fn input_time(&self) -> ClockBirthTime
Returns the original input clock time.
Sourcepub const fn resolved_date(&self) -> SolarDate
pub const fn resolved_date(&self) -> SolarDate
Returns the resolved local solar date.
Sourcepub const fn resolved_hour(&self) -> u8
pub const fn resolved_hour(&self) -> u8
Returns the resolved local hour (0..=23).
Sourcepub const fn resolved_minute(&self) -> u8
pub const fn resolved_minute(&self) -> u8
Returns the resolved local minute (0..=59).
Sourcepub const fn resolved_time_index(&self) -> u8
pub const fn resolved_time_index(&self) -> u8
Returns the derived iztro timeIndex (0..=12) for the resolved hour.
This preserves the early-Zi (0) versus late-Zi (12) distinction.
Sourcepub const fn resolved_time_branch(&self) -> EarthlyBranch
pub const fn resolved_time_branch(&self) -> EarthlyBranch
Returns the derived 时辰 (time branch) for the resolved hour.
Sourcepub const fn longitude_correction_minutes(&self) -> Option<f64>
pub const fn longitude_correction_minutes(&self) -> Option<f64>
Returns the applied longitude correction in minutes, if any.
Sourcepub const fn equation_of_time_minutes(&self) -> Option<f64>
pub const fn equation_of_time_minutes(&self) -> Option<f64>
Returns the applied equation-of-time minutes, if any.
Sourcepub const fn total_adjustment_minutes(&self) -> f64
pub const fn total_adjustment_minutes(&self) -> f64
Returns the total adjustment applied to the clock time, in minutes.
Sourcepub fn resolved_birth_time(&self) -> Result<BirthTime, ChartError>
pub fn resolved_birth_time(&self) -> Result<BirthTime, ChartError>
Returns the full birth-time variant for the resolved hour.